import chimera, numpy
from chimera import runCommand
from numpy import linalg
from StructBio.StructureOverlap.overlapper import Overlapper

def getAtom(prot, resPosition, atomName):
    for r in prot.residues:
        if r.id.position == resPosition:
            return r.findAtom(atomName)

#==============================================================================
# Mainline:
#==============================================================================
protP = chimera.openModels.open("1HHO", type = "PDB")[0]
protQ = chimera.openModels.open("1LJW", type = "PDB")[0]

runCommand("set bg_color white; sel #0-1:.A; sel invert; delete sel; ~sel")
runCommand("modelcolour pink #0; modelcolour turquoise #1")
overlap_L = []

for r in protP.residues:
    if r.type == "HEM":
        hrP = r
        
for r in protQ.residues:
    if r.type == "HEM":
        hrQ = r

overlap_L.append([hrP.findAtom("NA"), hrQ.findAtom("NA")])
overlap_L.append([hrP.findAtom("NB"), hrQ.findAtom("NB")])
overlap_L.append([hrP.findAtom("NC"), hrQ.findAtom("NC")])
overlap_L.append([hrP.findAtom("ND"), hrQ.findAtom("ND")])
                                  
overlapper = Overlapper(protP)
overlapper.moveToOverlap(overlap_L)

runCommand("window")
 
print "RMSD for overlap of heme rings: %6.4f" % overlapper.rmsdForOverlap()

proximalNE2Dist = linalg.norm(getAtom(protP, 87, "NE2").coord() - getAtom(protQ, 87, "NE2").coord())
print "Distance between NE2 atoms in proximal histidines: %6.4f" % proximalNE2Dist

distalNE2Dist = linalg.norm(getAtom(protP, 58, "NE2").coord() - getAtom(protQ, 58, "NE2").coord())
print "Distance between NE2 atoms in distal histidines: %6.4f" % distalNE2Dist



