import chimera
from chimera import runCommand

from StructBio.Utilities.miscFunctions import userSpecificationOfChains
from StructBio.StructureOverlap.sequencesLocalAlignment import SequencesLocalAlignment
from StructBio.StructureOverlap.overlapper import Overlapper

standardRes_T = ("ALA","ARG","ASN","ASP","CYS","GLN","GLU","GLY","HIS","ILE",
                 "LEU","LYS","MET","PHE","PRO","SER","THR","TRP","TYR","VAL")

def sequenceAndStructureSimilarity():

    prots_L = userSpecificationOfChains()

    targetProt = prots_L[0]

    targetProtRes_L = []
    for r in targetProt.residues:
        if r.findAtom("CA"):
            if r.type not in standardRes_T: continue
            targetProtRes_L.append(r)

    for ix in range(1,len(prots_L)):
        movingProtRes_L = []
        for r in prots_L[ix].residues:
            if r.findAtom("CA"):
                if r.type not in standardRes_T: continue
                movingProtRes_L.append(r)

        aligner = SequencesLocalAlignment(targetProtRes_L, movingProtRes_L, 8)
        print "Sequence alignment score for %4s and %4s is %4d" % (targetProt.name,
                                                                   prots_L[ix].name,
                                                                   aligner.maximumScore())
        overlapper = Overlapper(prots_L[ix])

        movingAtoms_L = []
        targetAtoms_L = []

        for pair in aligner.alignment_L:
            movingAtoms_L.append(pair[1].findAtom("CA"))
            targetAtoms_L.append(pair[0].findAtom("CA"))

        overlapper.moveToOverlap(zip(movingAtoms_L, targetAtoms_L))

    return prots_L

    
# -----------------------------------------------------------------------------
# Mainline:
# -----------------------------------------------------------------------------

runCommand("set bg_color white")

prots_L = sequenceAndStructureSimilarity()

for ix in range(1,len(prots_L)):
    runCommand("sel #" + str(prots_L[ix].id) + "; ~display sel; ~ribbon sel; ~sel")

print "Hit Enter to go through a succession of structural overlaps."
print "Type a space character before Enter to terminate."

runCommand("focus")

ix = 1
response = ""
while response != " ":
    runCommand("sel #" + str(prots_L[ix].id) + "; ~display sel; ribbon sel; ~sel")
    print "Overlapping: %4s and %4s:" % (prots_L[0].name, prots_L[ix].name)
    response = raw_input()
    runCommand("sel #" + str(prots_L[ix].id) + "; ~display sel; ~ribbon sel; ~sel")
    ix += 1
    if ix == len(prots_L): ix = 1
               







    
